# Py.Test plugin for Grunnur

[![pypi package][pypi-image]][pypi-link] ![License][pypi-license-image] [![Docs][rtd-image]][rtd-link] [![Coverage][cov-image]][cov-link] [![Code style: black][black-image]][black-link]

[pypi-image]: https://img.shields.io/pypi/v/pytest-grunnur
[pypi-link]: https://pypi.org/project/pytest-grunnur/
[pypi-license-image]: https://img.shields.io/pypi/l/pytest-grunnur
[rtd-image]: https://readthedocs.org/projects/pytest-grunnur/badge/?version=latest
[rtd-link]: https://pytest-grunnur.readthedocs.io/en/latest/
[cov-image]: https://codecov.io/gh/fjarri/pytest-grunnur/branch/master/graph/badge.svg
[cov-link]: https://codecov.io/gh/fjarri/pytest-grunnur
[black-image]: https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]: https://github.com/psf/black


This package contains a collection of helpers useful for testing ``grunnur``-based libraries and applications.
See [the Grunnur docs](https://grunnur.readthedocs.io/en/latest/) for more details about the main package, and [this package's documentation][rtd-link] for the list of provided hooks and fixtures.
